@@ -16,7 +16,8 @@ class FfmpegProcess:
         Accepts an optional ffmpeg_loglevel parameter to set the value of FFmpeg's -loglevel argument.
         """
         self._command = command
-        self._ffmpeg_args = command + ["-progress", "-", "-nostats", "-loglevel", ffmpeg_loglevel]
+        # pipe:1 sends the progress to stdout. See https://stackoverflow.com/a/54386052/13231825
+        self._ffmpeg_args = command + ["-progress", "pipe:1", "-nostats", "-loglevel", ffmpeg_loglevel]
 
     def run(self, progress_handler=None, ffmpeg_output_file=None):
         """
@@ -46,23 +47,23 @@ class FfmpegProcess:
             can_get_duration = False
 
         print(f"Running: {' '.join(self._ffmpeg_args)}")
-
-        with open(ffmpeg_output_file, "a") as f:
-            self._process = subprocess.Popen(
-                self._ffmpeg_args,
-                stdout=subprocess.PIPE,
-                stderr=f,
-            )
+        popen_args = [self._ffmpeg_args]
 
         if can_get_duration:
+            popen_args.append(stdout=subprocess.PIPE, stderr=f)
+
+            with open(ffmpeg_output_file, "a") as f:
+                self._process = subprocess.Popen(*popen_args)
+
             progress_bar = tqdm(
                 total=duration_secs,
                 unit="s",
                 dynamic_ncols=True
             )
-
             progress_bar.clear()
             previous_seconds_processed = 0
+        else:
+            self._process = subprocess.Popen(*popen_args)
 
         try:
             while self._process.poll() is None:
@@ -74,8 +75,6 @@ class FfmpegProcess:
                         seconds_increase = seconds_processed - previous_seconds_processed
                         progress_bar.update(seconds_increase)
                         previous_seconds_processed = seconds_processed
-                else:
-                    print(self._process.stdout.readline().decode().strip())
         except KeyboardInterrupt:
             progress_bar.close()
             self._process.kill()
